# Graph Utility functions

The graph utility functions module is a set of utility functions when working with graphs. 
They contain functions for plotting graphs, converting them and checking for certain properties,
for example checking if the graph asteroidal. The module is split into two main parts: 

1. Conversion functions, which handle conversions between different graph formats 
2. Non-conversion functions such as saving/writing graphs, plotting, etc. 

All utility functions can also be used outside the PHOTONAI Graph 
framework to handle conversions or check graph layouts.

## Graph Utility Functions

::: photonai_graph.GraphUtilities
